# Table of Contents

- [branding-settings](<./branding-settings.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Branding Settings](<./Branding-Settings.md>)
  - [Workspace Designs](<./Branding-Settings/Workspace-Designs.md>)
  - [Applying a Custom Design to a Workspace](<./Branding-Settings/Applying-a-Custom-Design-to-a-Workspace.md>)
